@@ -29,11 +29,6 @@
 /*****************************************************************************/
 /* Define all OS/CPU-Chip related symbols */
 
-/* ***** DOS variations */
-#if defined(__DJGPP__)
-#   define NV_DOS
-#endif
-
 /* ***** WINDOWS variations */
 #if defined(_WIN32) || defined(_WIN16)
 #   define NV_WINDOWS
@@ -71,8 +66,8 @@
 #   define NV_BSD
 #endif /* defined(__FreeBSD__) */
 
-/* XXXar don't define NV_UNIX on MacOSX or vxworks or dos or QNX */
-#if (defined(__unix__) || defined(__unix) ) && !defined(nvmacosx) && !defined(vxworks) && !defined(__DJGPP__) && !defined(NV_UNIX) && !defined(__QNX__) && !defined(__QNXNTO__)/* XXX until removed from Makefiles */
+/* XXXar don't define NV_UNIX on MacOSX or vxworks or QNX */
+#if (defined(__unix__) || defined(__unix) ) && !defined(nvmacosx) && !defined(vxworks) && !defined(NV_UNIX) && !defined(__QNX__) && !defined(__QNXNTO__)/* XXX until removed from Makefiles */
 #   define NV_UNIX
 #endif /* defined(__unix__) */
 
@@ -133,13 +128,19 @@
 #endif
 
 #if (defined(NV_MACINTOSH) && !(defined(__i386__) || defined(__x86_64__)))  || defined(__PPC__) || defined(__ppc)
+#if defined(__powerpc64__) && defined(__LITTLE_ENDIAN__)
+#   ifndef NVCPU_PPC64LE
+#   define NVCPU_PPC64LE           /* PPC 64-bit little endian */
+#   endif
+#else
 #   ifndef NVCPU_PPC
-#   define NVCPU_PPC               /* any PowerPC architecture */
+#   define NVCPU_PPC               /* any non-PPC64LE PowerPC architecture */
 #   endif
 #   ifndef NV_BIG_ENDIAN
 #   define NV_BIG_ENDIAN
 #   endif
 #endif
+#endif
 
 #if defined(__x86_64) || defined(AMD64) || defined(_M_AMD64)
 #    define NVCPU_X86_64           /* any x86-64 for any opsys */
@@ -195,7 +196,8 @@
 #endif
 
 #if defined(NVCPU_IA64) || defined(NVCPU_X86_64) || \
-    defined(NV_MACINTOSH_64) || defined(NVCPU_AARCH64)
+    defined(NV_MACINTOSH_64) || defined(NVCPU_AARCH64) || \
+    defined(NVCPU_PPC64LE)
 #   define NV_64_BITS          /* all architectures where pointers are 64 bits */
 #else
 /* we assume 32 bits. I don't see a need for NV_16_BITS. */
@@ -318,6 +320,11 @@
 #else
 #define NVCPU_IS_PPC 0
 #endif
+#if defined(NVCPU_PPC64LE)
+#define NVCPU_IS_PPC64LE 1
+#else
+#define NVCPU_IS_PPC64LE 0
+#endif
 #if defined(NVCPU_ARM)
 #define NVCPU_IS_ARM 1
 #else
@@ -353,7 +360,7 @@
 #else
 #define NVCPU_IS_64_BITS 0
 #endif
-#if defined(NVCPU_ARM)
+#if defined(NVCPU_FAMILY_ARM)
 #define NVCPU_IS_PCIE_CACHE_COHERENT 0
 #else
 #define NVCPU_IS_PCIE_CACHE_COHERENT 1
