@@ -558,16 +558,6 @@ void NV_API_CALL os_flush_cpu_write_combine_buffer(void)
     sfence_action_func(NULL);
 }
 
-NV_STATUS NV_API_CALL os_raise_smp_barrier(void)
-{
-    return NV_ERR_NOT_SUPPORTED;
-}
-
-NV_STATUS NV_API_CALL os_clear_smp_barrier(void)
-{
-    return NV_ERR_NOT_SUPPORTED;
-}
-
 NV_STATUS NV_API_CALL os_alloc_mutex(void **mutex)
 {
     NV_STATUS status;
@@ -710,10 +700,9 @@ BOOL NV_API_CALL os_is_efi_enabled(void)
     return FALSE;
 }
 
-NV_STATUS NV_API_CALL os_get_efi_screen_info(
+NV_STATUS NV_API_CALL os_get_screen_info(
     NvU64 *pPhysicalAddress,
-    NvU32 *pHeight,
-    NvU32 *pPitch
+    NvU64 *pFbSize
 )
 {
     return NV_ERR_NOT_SUPPORTED;
@@ -796,16 +785,6 @@ NV_STATUS NV_API_CALL os_get_address_space_info(
     return NV_ERR_NOT_SUPPORTED;
 }
 
-NV_STATUS NV_API_CALL os_alloc_smp_barrier(void)
-{
-    return NV_OK;
-}
-
-NV_STATUS NV_API_CALL os_free_smp_barrier(void)
-{
-    return NV_OK;
-}
-
 NV_STATUS NV_API_CALL os_get_version_info(os_version_info * pOsVersionInfo)
 {
     return NV_ERR_NOT_SUPPORTED;
@@ -881,3 +860,9 @@ NV_STATUS NV_API_CALL os_match_mmap_offset(
 
     return NV_ERR_OBJECT_NOT_FOUND;
 }
+
+NV_STATUS NV_API_CALL os_get_euid(NvU32 *pSecToken)
+{
+    *pSecToken = (NvU32)CURTHREAD->td_ucred->cr_uid;
+    return NV_OK;
+}
