@@ -1453,15 +1453,11 @@ void NV_API_CALL nv_verify_pci_config(
     nvidia_pci_check_config_space(sp, dev, check_the_bars, FALSE, FALSE);
 }
 
-void* NV_API_CALL nv_get_smu_state(void)
-{
-    return NULL;
-}
-
 NV_STATUS NV_API_CALL nv_dma_map_pages(
     nv_state_t *nv,
     NvU64       page_count,
     NvU64      *pte_array,
+    NvBool      contig,
     void      **priv
 )
 {
@@ -1478,6 +1474,45 @@ NV_STATUS NV_API_CALL nv_dma_unmap_pages(
     return NV_ERR_NOT_SUPPORTED;
 }
 
+NV_STATUS NV_API_CALL nv_dma_map_alloc(
+    nv_state_t *nv,
+    NvU64       page_count,
+    NvU64      *va_array,
+    void      **priv
+)
+{
+    return NV_ERR_NOT_SUPPORTED;
+}
+
+NV_STATUS NV_API_CALL nv_dma_unmap_alloc(
+    nv_state_t *nv,
+    NvU64       page_count,
+    NvU64      *va_array,
+    void      **priv
+)
+{
+    return NV_ERR_NOT_SUPPORTED;
+}
+
+NV_STATUS NV_API_CALL nv_dma_map_peer(
+    nv_state_t    *nv,
+    nv_aperture_t *aperture,
+    NvU64          page_count,
+    NvU64         *va_array
+)
+{
+    return NV_ERR_NOT_SUPPORTED;
+}
+
+NV_STATUS NV_API_CALL nv_dma_unmap_peer(
+    nv_state_t *nv,
+    NvU64       page_count,
+    NvU64      *va_array
+)
+{
+    return NV_ERR_NOT_SUPPORTED;
+}
+
 NV_STATUS NV_API_CALL nv_log_error(
     nv_state_t *nv,
     NvU32       error_number,
@@ -1519,3 +1554,29 @@ NV_STATUS NV_API_CALL nv_pci_trigger_recovery(
 {
     return NV_ERR_NOT_SUPPORTED;
 }
+
+NvBool NV_API_CALL nv_requires_dma_remap(
+    nv_state_t *nv
+)
+{
+    return NV_FALSE;
+}
+
+NV_STATUS NV_API_CALL nv_register_user_pages(
+    nv_state_t *nv,
+    NvU64       page_count,
+    NvU64      *phys_addr,
+    void      **priv
+)
+{
+    return NV_OK;
+}
+
+NV_STATUS NV_API_CALL nv_unregister_user_pages(
+    nv_state_t *nv,
+    NvU64       page_count,
+    void      **priv
+)
+{
+    return NV_OK;
+}
