@@ -88,7 +88,7 @@ typedef double             NvF64; /* IEEE Double Precision (S1E11M52)        */
 #define NvU16_BUILD(msb, lsb)  (((msb) << 8)|(lsb))
 
 #if defined(macosx) || defined(MACOS) || defined(NV_MACINTOSH) || \
-    defined(NV_MACINTOSH_64)
+    defined(NV_MACINTOSH_64) || defined(NVCPU_AARCH64)
 typedef char*              NVREGSTR;
 #else
 typedef NvU8*              NVREGSTR;
