@@ -117,10 +117,6 @@ void        NV_API_CALL  os_dbg_breakpoint           (void);
 void        NV_API_CALL  os_dbg_set_level            (NvU32);
 NvU32       NV_API_CALL  os_get_cpu_count            (void);
 NvU32       NV_API_CALL  os_get_cpu_number           (void);
-NV_STATUS   NV_API_CALL  os_alloc_smp_barrier        (void);
-NV_STATUS   NV_API_CALL  os_free_smp_barrier         (void);
-NV_STATUS   NV_API_CALL  os_raise_smp_barrier        (void);
-NV_STATUS   NV_API_CALL  os_clear_smp_barrier        (void);
 NV_STATUS   NV_API_CALL  os_disable_console_access   (void);
 NV_STATUS   NV_API_CALL  os_enable_console_access    (void);
 NV_STATUS   NV_API_CALL  os_registry_init            (void);
@@ -152,13 +148,13 @@ BOOL        NV_API_CALL  os_is_efi_enabled           (void);
 NvBool      NV_API_CALL  os_is_xen_dom0              (void);
 NvBool      NV_API_CALL  os_is_vgx_hyper             (void);
 NV_STATUS   NV_API_CALL  os_inject_vgx_msi           (NvU16, NvU64, NvU32);
-NV_STATUS   NV_API_CALL  os_get_efi_screen_info      (NvU64 *, NvU32 *, NvU32 *);
+NV_STATUS   NV_API_CALL  os_get_screen_info          (NvU64 *, NvU64 *);
 void        NV_API_CALL  os_bug_check                (NvU32, const char *);
 NV_STATUS   NV_API_CALL  os_lock_user_pages          (void *, NvU64, void **);
 NV_STATUS   NV_API_CALL  os_lookup_user_io_memory    (void *, NvU64, NvU64 **);
 NV_STATUS   NV_API_CALL  os_unlock_user_pages        (NvU64, void *);
 NV_STATUS   NV_API_CALL  os_match_mmap_offset        (void *, NvU64, NvU64 *);
-
+NV_STATUS   NV_API_CALL  os_get_euid                 (NvU32 *);
 /*
  * ---------------------------------------------------------------------------
  *
